@@ -128,19 +128,7 @@
 # include <sys/param.h>
 #endif
 
-#if HAVE_SYSLOG
-# define syslog(...) syslog(__VA_ARGS__)
-# if HAVE_OPENLOG
-#  define openlog(...) openlog(__VA_ARGS__)
-# else
-#  define openlog(...) /**/
-# endif
-# if HAVE_CLOSELOG
-#  define closelog(...) closelog(__VA_ARGS__)
-# else
-#  define closelog(...) /**/
-# endif
-#else
+#if !HAVE_SYSLOG
 # define syslog(...) /**/
 # define openlog(...) /**/
 # define closelog(...) /**/
@@ -200,6 +188,10 @@
 #define MODE_LOCAL  0x04
 #define MODE_LOG    0x08
 
+#ifndef COLLECTD_GRP_NAME
+# define COLLECTD_GRP_NAME "collectd"
+#endif
+
 #ifndef COLLECTD_STEP
 #  define COLLECTD_STEP "10"
 #endif
